/// <reference types="node" />
import * as S3 from '@aws-sdk/client-s3';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { IS3Helper } from './interface';
import { Readable } from 'stream';
import { Metadata } from './any';
export declare class S3Helper extends BaseClass implements IS3Helper {
    private Repository;
    private Options;
    constructor(logger: ILogger, repository?: S3.S3, options?: S3.S3ClientConfig);
    CopyObjectAsync(sourceBucket: string, sourceKey: string, destinationBucket: string, destinationKey: string): Promise<S3.CopyObjectOutput>;
    CreateBucketAsync(name: string): Promise<S3.CreateBucketOutput>;
    DeleteBucketAsync(name: string): Promise<any>;
    DeleteObjectAsync(bucket: string, key: string): Promise<S3.DeleteObjectOutput>;
    DeleteObjectsAsync(bucket: string, keys: string[]): Promise<S3.DeleteObjectsOutput>;
    DeleteObjectTagsAsync(bucket: string, key: string): Promise<any>;
    GetBucketMetadataAsync(bucket: string): Promise<any>;
    GetObjectAsJsonAsync<T>(bucket: string, key: string): Promise<T>;
    GetObjectAsync(bucket: string, key: string): Promise<S3.GetObjectOutput>;
    GetObjectContentsAsync(bucket: string, key: string): Promise<Readable | undefined>;
    GetObjectMetadataAsync(bucket: string, key: string): Promise<Metadata | undefined>;
    GetObjectTagsAsync(bucket: string, key: string): Promise<S3.Tag[]>;
    GetSignedUrlDownload(bucket: string, key: string, timeoutInMinutes?: number): Promise<string>;
    GetSignedUrlUpload(bucket: string, key: string, timeoutInMinutes?: number, acl?: S3.ObjectCannedACL): Promise<string>;
    MoveObjectAsync(sourceBucket: string, sourceKey: string, destinationBucket: string, destinationKey: string): Promise<void>;
    MultipartUploadCompleteAsync(bucket: string, key: string, uploadId: string): Promise<S3.CompleteMultipartUploadOutput>;
    MultipartUploadStartAsync(bucket: string, key: string, acl?: S3.ObjectCannedACL): Promise<S3.CreateMultipartUploadOutput>;
    MultipartUploadUploadPartAsync(bucket: string, key: string, uploadId: string, uploadPart: number, contents: string): Promise<S3.UploadPartOutput>;
    PutObjectAsync(bucket: string, key: string, contents: string | Readable, acl?: S3.ObjectCannedACL, encoding?: string): Promise<S3.PutObjectOutput>;
    SetObjectTagAsync(bucket: string, key: string, tagName: string, tagValue: string): Promise<S3.PutObjectTaggingOutput>;
    SetObjectTagsAsync(bucket: string, key: string, tags: S3.Tag[]): Promise<S3.PutObjectTaggingOutput>;
}
